==> gpac_0.4.4.orig.tar.gz: gpac-0.4.4/applications/osmophone/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft eMbedded Visual C++ generated include file.
// Used by osmophone.rc
//
#define IDS_APP_TITLE                   1
#define IDS_CLASSNAME                   1
#define IDS_HELLO                       2
#define IDC_KEYTEST2                    3
#define IDS_WINDOWNAME                  4
#define IDS_APPNAME                     5
#define IDI_KEYTEST2                    101
#define IDI_ICON                        101
#define IDM_MENU                        102
#define IDM_MAIN_MENU                   102
#define IDM_MAIN_MENU1                  102
#define IDD_ABOUTBOX                    103
#define IDD_APPABOUT                    104
#define IDD_OPENFILE                    105
#define IDD_FILEDIALOG                  105
#define IDR_MENU_OPEN                   106
#define IDR_ABOUT_MENU                  107
#define IDM_MAIN_MENU2                  108
#define IDM_MAIN_MENUITEM1              401
#define IDM_MAIN_MENUITEM2              402
#define IDS_MAIN_MENUITEM1              410
#define IDS_MAIN_MENUITEM2              412
#define IDC_EDIT1                       1001
#define IDC_DIRNAME                     1001
#define IDC_LIST1                       1002
#define IDC_FILELIST                    1002
#define IDC_LIST2                       1003
#define IDM_FILE_EXIT                   40002
#define IDM_HELP_ABOUT                  40003
#define IDM_GRAB                        40004
#define IDM_RELEASE                     40005
#define ID_FILE_SHOW_WMKEYDOWN          40006
#define ID_FILE_SHOW_WMKEYUP            40007
#define ID_FILE_SHOW_WMCHAR             40008
#define ID_FILE_SHOW_WMMOUSEMOVE        40009
#define ID_FILE_SHOW_WMLBUTTONDOWN      40010
#define ID_FILE_SHOW_WMLBUTTONDBLCLK    40011
#define ID_FILE_SHOW_WMLBUTTONUP        40012
#define ID_FILE_SHOW_WMRBUTTONDOWN      40013
#define ID_FILE_SHOW_WMRBUTTONUP        40014
#define ID_FILE_SHOW_WMRBUTTONDBLCLK    40015
#define IDM_ITEM_QUIT                   40016
#define IDS_CAP_QUIT                    40018
#define ID_MENU_FILE                    40019
#define IDS_CAP_FILE                    40021
#define IDM_FILE_OPEN                   40022
#define IDS_CAP_EXIT                    40023
#define IDM_MENU_VIEW                   40024
#define IDS_CAP_VIEW                    40025
#define IDM_FILE_OPEN_URL               40026
#define IDM_OPEN_FILE1                  40030
#define IDM_OPEN_FILE2                  40031
#define IDM_OPEN_FILE3                  40032
#define IDM_OPEN_FILE4                  40033
#define IDM_OPEN_FILE5                  40034
#define IDM_OPEN_FILE6                  40035
#define IDM_OPEN_FILE7                  40036
#define IDM_OPEN_FILE8                  40037
#define IDM_OPEN_FILE9                  40038
#define IDM_OPEN_FILE10                 40039
#define ID_VIEW                         40040
#define IDM_OF_VIEW_ALL                 40041
#define IDS_CAP_OK                      40044
#define IDS_CAP_MENUITEM40045           40046
#define ID_SELECT                       40047
#define IDS_CAP_SELECT                  40049
#define IDM_OF_PL_ADD                   40050
#define IDM_OF_PLAYLIST                 40051
#define IDM_OF_PL_REM                   40052
#define IDM_VIEW_FS                     40053
#define IDM_VIEW_ABOUT                  40054
#define IDM_ABOUT_OK                    40055
#define IDM_VIEW_STATUS                 40057
#define IDM_VIEW_3DREND                 40058
#define ID_NAVIGATE                     40059
#define IDS_CAP_NAVIGATE                40061
#define IDM_NAV_NONE                    40062
#define IDM_NAV_SLIDE                   40063
#define IDM_SELECT                      40064
#define IDM_NAV_RESET                   40065
#define IDM_MENU_SWITCH                 40066
#define ID_OPTION                       40067
#define IDS_CAP_OPTION                  40069
#define ID_MENUITEM40071                40071
#define IDS_CAP_MENUITEM40072           40073
#define IDM_NAV_WALK                    40074
#define IDM_NAV_FLY                     40075
#define IDM_NAV_EXAMINE                 40076
#define IDM_NAV_HEADLIGHT               40077
#define IDM_NAV_GRAVITY                 40078
#define IDM_NAV_COL_NONE                40079
#define IDM_NAV_COL_REG                 40080
#define IDM_NAV_COL_DISP                40081
#define IDM_VIEW_AR_NONE                40082
#define IDM_VIEW_AR_FILL                40083
#define IDM_VIEW_AR_4_3                 40084
#define IDM_VIEW_AR_16_9                40085
#define IDM_OF_PL_UP                    40088
#define IDM_OF_PL_DOWN                  40089
#define ID_OF_VIEW                      40090
#define IDM_OF_PL_ACT                   40091
#define IDS_CAP_MENUITEM40092           40093
#define IDS_CAP_ADD                     40095
#define IDM_OF_PL_CLEAR                 40096
#define IDM_FILE_RELOAD                 40097
#define IDM_VIEW_CPU                    40098
#define IDM_FILE_PAUSE                  40099
#define IDM_VIEW_LOW_RATE               40100
#define IDM_VIEW_DIRECT                 40101
#define IDM_VIEW_SVG_LOAD               40102
#define IDS_CAP_DISABLE_PLAYLIST        40103

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        111
#define _APS_NEXT_COMMAND_VALUE         40103
#define _APS_NEXT_CONTROL_VALUE         1004
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif

==> gpac_0.4.5.orig.tar.gz: gpac-0.4.5/applications/osmophone/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft eMbedded Visual C++ generated include file.
// Used by osmophone.rc
//
#define IDS_CLASSNAME                   1
#define IDS_WINDOWNAME                  4
#define IDS_APPNAME                     5
#define IDI_ICON                        101
#define IDM_MENU                        102
#define IDM_MAIN_MENU                   102
#define IDM_MAIN_MENU1                  102
#define IDD_ABOUTBOX                    103
#define IDD_APPABOUT                    104
#define IDD_OPENFILE                    105
#define IDD_FILEDIALOG                  105
#define IDR_MENU_OPEN                   106
#define IDR_ABOUT_MENU                  107
#define IDM_MAIN_MENU2                  108
#define IDM_MAIN_MENUITEM1              401
#define IDM_MAIN_MENUITEM2              402
#define IDS_MAIN_MENUITEM1              410
#define IDS_MAIN_MENUITEM2              412
#define IDC_EDIT1                       1001
#define IDC_DIRNAME                     1001
#define IDC_LIST1                       1002
#define IDC_FILELIST                    1002
#define IDC_LIST2                       1003
#define IDM_FILE_EXIT                   40002
#define IDM_HELP_ABOUT                  40003
#define IDM_GRAB                        40004
#define IDM_RELEASE                     40005
#define ID_FILE_SHOW_WMKEYDOWN          40006
#define ID_FILE_SHOW_WMKEYUP            40007
#define ID_FILE_SHOW_WMCHAR             40008
#define ID_FILE_SHOW_WMMOUSEMOVE        40009
#define ID_FILE_SHOW_WMLBUTTONDOWN      40010
#define ID_FILE_SHOW_WMLBUTTONDBLCLK    40011
#define ID_FILE_SHOW_WMLBUTTONUP        40012
#define ID_FILE_SHOW_WMRBUTTONDOWN      40013
#define ID_FILE_SHOW_WMRBUTTONUP        40014
#define ID_FILE_SHOW_WMRBUTTONDBLCLK    40015
#define IDM_ITEM_QUIT                   40016
#define IDS_CAP_QUIT                    40018
#define ID_MENU_FILE                    40019
#define IDS_CAP_FILE                    40021
#define IDM_FILE_OPEN                   40022
#define IDS_CAP_EXIT                    40023
#define IDM_MENU_VIEW                   40024
#define IDS_CAP_VIEW                    40025
#define IDM_FILE_OPEN_URL               40026
#define IDM_OPEN_FILE1                  40030
#define IDM_OPEN_FILE2                  40031
#define IDM_OPEN_FILE3                  40032
#define IDM_OPEN_FILE4                  40033
#define IDM_OPEN_FILE5                  40034
#define IDM_OPEN_FILE6                  40035
#define IDM_OPEN_FILE7                  40036
#define IDM_OPEN_FILE8                  40037
#define IDM_OPEN_FILE9                  40038
#define IDM_OPEN_FILE10                 40039
#define ID_VIEW                         40040
#define IDM_OF_VIEW_ALL                 40041
#define IDS_CAP_OK                      40044
#define IDS_CAP_MENUITEM40045           40046
#define ID_SELECT                       40047
#define IDS_CAP_SELECT                  40049
#define IDM_OF_PL_ADD                   40050
#define IDM_OF_PLAYLIST                 40051
#define IDM_OF_PL_REM                   40052
#define IDM_VIEW_FS                     40053
#define IDM_VIEW_ABOUT                  40054
#define IDM_ABOUT_OK                    40055
#define IDM_VIEW_STATUS                 40057
#define IDM_VIEW_FORCEGL                40058
#define ID_NAVIGATE                     40059
#define IDS_CAP_NAVIGATE                40061
#define IDM_NAV_NONE                    40062
#define IDM_NAV_SLIDE                   40063
#define IDM_SELECT                      40064
#define IDM_NAV_RESET                   40065
#define IDM_MENU_SWITCH                 40066
#define ID_OPTION                       40067
#define IDS_CAP_OPTION                  40069
#define ID_MENUITEM40071                40071
#define IDS_CAP_MENUITEM40072           40073
#define IDM_NAV_WALK                    40074
#define IDM_NAV_FLY                     40075
#define IDM_NAV_EXAMINE                 40076
#define IDM_NAV_HEADLIGHT               40077
#define IDM_NAV_GRAVITY                 40078
#define IDM_NAV_COL_NONE                40079
#define IDM_NAV_COL_REG                 40080
#define IDM_NAV_COL_DISP                40081
#define IDM_VIEW_AR_NONE                40082
#define IDM_VIEW_AR_FILL                40083
#define IDM_VIEW_AR_4_3                 40084
#define IDM_VIEW_AR_16_9                40085
#define IDM_OF_PL_UP                    40088
#define IDM_OF_PL_DOWN                  40089
#define ID_OF_VIEW                      40090
#define IDM_OF_PL_ACT                   40091
#define IDS_CAP_MENUITEM40092           40093
#define IDS_CAP_ADD                     40095
#define IDM_OF_PL_CLEAR                 40096
#define IDM_FILE_LOG_RTI                40097
#define IDM_VIEW_CPU                    40098
#define IDM_FILE_PAUSE                  40099
#define IDM_VIEW_LOW_RATE               40100
#define IDM_VIEW_DIRECT                 40101
#define IDM_VIEW_SVG_LOAD               40102
#define IDS_CAP_DISABLE_PLAYLIST        40103
#define ID_FILE_CUT_PASTE               40104

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        111
#define _APS_NEXT_COMMAND_VALUE         40105
#define _APS_NEXT_CONTROL_VALUE         1004
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif
